<?php
/**
 * Kids EducationTheme Customizer.
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */


function kids_education_pro_customize_register( $wp_customize ) {
	$options = kids_education_pro_get_theme_options();

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load customize custom controls functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize sanitize functions.
	require get_template_directory() . '/inc/customizer/sanitize.php';

	// Load customize custom controls functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	// Add menu sticky enable section
	$wp_customize->add_section( 'kids_education_pro_additional_menu_options', array(
		'title'             => esc_html__( 'Additional Options','kids-education-pro' ),
		'description'       => esc_html__( 'Additional menu options.', 'kids-education-pro' ),
		'panel'             => 'nav_menus',
		'priority'          => 5
	) );

	// Add primary menu sticky setting and control.
	$wp_customize->add_setting( 'kids_education_pro_theme_options[header_menu_sticky_enable]', array(
		'default'           => $options['header_menu_sticky_enable'],
		'sanitize_callback' => 'kids_education_pro_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[header_menu_sticky_enable]', array(
		'label'             => esc_html__( 'Make Header Menu Sticky', 'kids-education-pro' ),
		'section'           => 'kids_education_pro_additional_menu_options',
		'type'              => 'checkbox',
	) );

	// Add color setting and control.
	$wp_customize->add_setting( 'kids_education_pro_theme_options[color_layout]', array(
		'default'           => $options['color_layout'],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[color_layout]', array(
		'label'             => esc_html__( 'Theme Color Layout', 'kids-education-pro' ),
		'section'           => 'colors',
	) ) );

	/**
	* Add panel for page template
	*/
	$wp_customize->add_panel( 'kids_education_pro_page_template_panel' , array(
	    'title'      => esc_html__( 'Page Templates','kids-education-pro' ),
	    'description'=> esc_html__( 'Kids Education Pro available page templates.', 'kids-education-pro' ),
	    'priority'   => 120,
	) );

	//load contact page template
	require get_template_directory() . '/inc/customizer/page-template/contact-page.php';

	//load portfolio page template
	require get_template_directory() . '/inc/customizer/page-template/portfolio-page.php';

	/**
	* Add panel for different home page sections
	*
	*/

	if( class_exists( 'Tp_Education') ){
		$description = esc_html__( 'Kids Education Pro available sections.', 'kids-education-pro' );
	} else {
		$description = sprintf( esc_html__( 'Install and Activate %1$sTp Education%2$s plugin to Function Recent, Team, Gallery and Testimonial sections Properly.', 'kids-education-pro'), '<a href="'. esc_url( 'https://wordpress.org/plugins/tp-education/' ) .'">', '</a>' );
	}

	$wp_customize->add_panel( 'kids_education_pro_sections_panel' , array(
	    'title'      => esc_html__( 'Sections','kids-education-pro' ),
	    'description'=> $description,
	    'priority'   => 130,
	) );

	//load main slider section
	require get_template_directory() . '/inc/customizer/sections/main-slider.php';

	//load info content section
	require get_template_directory() . '/inc/customizer/sections/info-content.php';

	//load features section
	require get_template_directory() . '/inc/customizer/sections/features.php';

	//Load search section
	require get_template_directory() . '/inc/customizer/sections/search-course.php';

	//Load recent section
	require get_template_directory() . '/inc/customizer/sections/recent.php';

	//load counter section
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	//Load team section
	require get_template_directory() . '/inc/customizer/sections/team.php';

	//load gallery section
	require get_template_directory() . '/inc/customizer/sections/gallery.php';

	//Load testimonial section
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	//Load category blog section
	require get_template_directory() . '/inc/customizer/sections/category-blog.php';

	// Add panel for common theme options
	$wp_customize->add_panel( 'kids_education_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','kids-education-pro' ),
	    'description'=> esc_html__( 'Kids Education Theme Options.', 'kids-education-pro' ),
	    'priority'   => 150,
	) );
	// Animation
	require get_template_directory() . '/inc/customizer/theme-options/animation.php';
	
	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// blog page option
	require get_template_directory() . '/inc/customizer/theme-options/blog-page.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load excerpt option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load search placeholder option
	require get_template_directory() . '/inc/customizer/theme-options/search-placeholder.php';

	// load breadcrumb option
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load post navigation option
	require get_template_directory() . '/inc/customizer/theme-options/post-navigation.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	if ( version_compare( $GLOBALS['wp_version'], '4.7', '<' ) ) {
		// load custom css option
		require get_template_directory() . '/inc/customizer/theme-options/custom-css.php';
	}

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';
}
add_action( 'customize_register', 'kids_education_pro_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function kids_education_pro_customize_preview_js() {
	wp_enqueue_script( 'kids_education_pro_customizer', get_template_directory_uri() . '/assets/js/customizer.min.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'kids_education_pro_customize_preview_js' );


if ( !function_exists( 'kids_education_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function kids_education_pro_reset_options() {
		$options = kids_education_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'kids_education_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'kids_education_pro_reset_options' );

// Add Custom Css
function kids_education_pro_inline_css() {
	$options = kids_education_pro_get_theme_options();
	$custom_css = !empty( $options['custom_css'] ) ? $options['custom_css'] : '';
	$color_layout = !empty( $options['color_layout'] ) ? $options['color_layout'] : '';
	$homepage_background_option = $options['static_homepage_background_property'];
	$header_text_color = get_header_textcolor(); // get header text color

	$color_layout_css = '';

	if ( get_theme_support( 'custom-header', 'default-text-color' ) != $header_text_color ) {
		if ( ! display_header_text() ) :
			$header_color = "#site-header .site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
			}";
		// If the user has set a custom color for the text use that.
		else :
			$header_color = "#site-header .site-title a,
			.site-description {
				color: #" . esc_attr( $header_text_color ) . "}";
		endif; 

		$color_layout_css .= $header_color;
	}

	if( $options['enable_frontpage_content'] ){

		$homepage_css = !empty( $options['static_homepage_background_image'] ) ? '.home .cloud-background.page-section{ background-image:url('.  esc_url( $options['static_homepage_background_image'] ) .')}' : '';

		if( 'background_color' == $homepage_background_option ){
			$homepage_css = !empty( $options['static_homepage_background_color'] ) ? '.home .cloud-background.page-section{ background-color:'.  esc_attr( $options['static_homepage_background_color'] ) .';}' : '';
		}
		$color_layout_css .= $homepage_css;
	}	

	if( !empty( $color_layout ) ){
		$color_layout_css .= '
		/*--------------- BACKGROUND COLORS ----------------------*/
		#features .column-wrapper:nth-child(1n) .icon-container, 
		#features .column-wrapper:nth-child(2n) .icon-container, 
		#features .column-wrapper:nth-child(3n) .icon-container, 
		#features .column-wrapper:nth-child(4n) .icon-container,
		#search-course-tab ul.tabs li:nth-child(1n) a,
		#search-course-tab ul.tabs li.active:nth-child(3n),
		#search-course-tab ul.tabs li.active:nth-child(2n),
		#search-course-tab ul.tabs li.active:nth-child(1n),
		.search-wrapper input[type="submit"]:hover, .btn-blue:hover, 
		.wpcf7-form input[type="submit"]:hover, 
		#comments #submit:hover, 
		.add_to_cart_button:hover,
		.search-wrapper input[type="submit"],
		.btn-default:hover,
		.slick-next:hover, 
		.slick-prev:hover,
		.btn-blue,
		#counter .column-wrapper:nth-child(1n):hover .fa,
		#counter .column-wrapper:nth-child(2n):hover .fa,
		#counter .column-wrapper:nth-child(3n):hover .fa,
		#counter .column-wrapper:nth-child(3n):hover .fa,
		.team-img .hover-content h6,
		.read-more::after,
		.backtotop,
		.blue-overlay,
		.page-content .search-submit,
		.page-numbers.current, .page-numbers:hover,
		.wpcf7-form input[type="submit"], 
		#comments #submit,
		.price_slider_amount .button,
		.add_to_cart_button,
		nav.portfolio-filter ul li.active a, 
		nav.portfolio-filter ul li a:hover {
			background-color: '. esc_attr( $color_layout ) .';
		}

		/*--------------- END BACKGROUND COLORS ----------------------*/


		/*--------------- TEXT COLORS ----------------------*/
		.color-yellow,
		.entry-title,
		#features .column-wrapper:nth-child(1n) .title a, 
		#features .column-wrapper:nth-child(1n):hover .icon-container .fa,
		#features .column-wrapper:nth-child(2n) .title a, 
		#features .column-wrapper:nth-child(2n):hover .icon-container .fa,
		#features .column-wrapper:nth-child(3n) .title a, 
		#features .column-wrapper:nth-child(3n):hover .icon-container .fa,
		#features .column-wrapper:nth-child(4n) .title a, 
		#features .column-wrapper:nth-child(4n):hover .icon-container .fa,
		#counter .column-wrapper:nth-child(1n) h4, 
		#counter .column-wrapper:nth-child(1n) h6, 
		#counter .column-wrapper:nth-child(1n) .fa,
		#team-members .entry-title,
		.member-position,
		.read-more:hover,
		.site-footer .widget .address-block a:hover,
		.picker_close, 
		.picker_close:hover, 
		.picker_close:focus,
		.portfolio-item .hovercontent .fa,
		.page-title .entry-title,
		#secondary ul li a:hover, 
		.site-footer ul li a:hover, 
		#secondary ul li:hover:before, 
		.site-footer ul li:hover:before, 
		#contact-address .address-block small a:hover, 
		.blog-title a:hover,
		#contact-address .address-block li:nth-child(1n) .icon-container .fa, 
		#contact-address .address-block li:nth-child(1n) span,
		.author-name a,
		.related-post-title,
		.reply a,
		time:hover, article .entry-title a:hover, 
		.comment-meta .url:hover,
		#reply-title, 
		.comments-title,
		#breadcrumb-list a:hover,
		ul.tabs.shop-tab,
		ul.tabs.shop-tab .fa,
		.loader-container .fa {
		    color: '. esc_attr( $color_layout ) .';
		}
		.read-more {
			color: #fff;
		}

		/*--------------- END TEXT COLORS ----------------------*/


		/*--------------- HOVER BACKGROUND COLORS ----------------------*/

		.search-wrapper input[type="submit"]:hover,
		.btn-blue:hover,
		.portfolio-item:hover .blue-overlay, 
		.portfolio-item:hover .hovercontent {
			opacity: 0.8;
		}

		/*--------------- END HOVER BACKGROUND COLORS ----------------------*/



		/*--------------- BORDER COLOR ----------------------*/
		#features .column-wrapper:nth-child(1n):hover .icon-container:after,
		#features .column-wrapper:nth-child(2n):hover .icon-container:after,
		#features .column-wrapper:nth-child(3n):hover .icon-container:after,
		#features .column-wrapper:nth-child(4n):hover .icon-container:after,
		#counter .column-wrapper:nth-child(1n) .fa,
		#counter .column-wrapper:nth-child(2n) .fa,
		#counter .column-wrapper:nth-child(3n) .fa,
		#counter .column-wrapper:nth-child(4n) .fa,
		.page-numbers.current, .page-numbers:hover,
		#contact-address .address-block li:nth-child(1n) .icon-container {
			border-color: '. esc_attr( $color_layout ) .';
		}
		#search-course-tab ul.tabs li.active:nth-child(1n):after, 
		#search-course-tab ul.tabs li.active:nth-child(2n):after, 
		#search-course-tab ul.tabs li.active:nth-child(3n):after {
			border-top-color: '. esc_attr( $color_layout ) .';
		}
		#features .column-wrapper:nth-child(1n):hover .icon-container,
		#features .column-wrapper:nth-child(2n):hover .icon-container,
		#features .column-wrapper:nth-child(3n):hover .icon-container,
		#features .column-wrapper:nth-child(4n):hover .icon-container {
			background-color: transparent;
		}

		/*--------------- END BORDER COLOR ----------------------';
	}
	$css = $color_layout_css;	
	$css .= $custom_css;
	wp_add_inline_style( 'kids-education-pro-style', $css );
}
add_action( 'wp_enqueue_scripts', 'kids_education_pro_inline_css', 10 );

// migrate custom css to core add css
function kids_education_pro_custom_css_migrate() {
	$options = kids_education_pro_get_theme_options();
	if ( function_exists( 'wp_update_custom_css_post' ) ) {
		$custom_css = ! empty( $options['custom_css'] ) ? $options['custom_css'] : '';
		if ( ! empty( $custom_css ) ) {
			$core_css = wp_get_custom_css(); // Preserve any CSS already added to the core option.
			$return = wp_update_custom_css_post( $core_css . $custom_css );
			if ( ! is_wp_error( $return ) ) {
				// Remove from theme.
	            $options['custom_css'] = '';
	            set_theme_mod( 'kids_education_theme_options', $options );
			}
		}
	}
}

add_action( 'after_setup_theme', 'kids_education_pro_custom_css_migrate' );