<?php
/**
* Homepage (Static ) options
*
* @package Theme Palace
* @subpackage Kids Education Pro
* @since Kids Education Pro 1.0
*/

// Add excerpt section
$wp_customize->add_section( 'kids_education_pro_static_homepage', array(
	'title'             => esc_html__( 'Static Homepage','kids-education-pro' ),
	'description'       => esc_html__( 'Options for static homepage.', 'kids-education-pro' ),
	'panel'             => 'kids_education_pro_theme_options_panel'
) );

// Homepage (Static ) setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[enable_frontpage_content]', array(
	'sanitize_callback'   => 'kids_education_pro_sanitize_checkbox',
	'default'             => $options['enable_frontpage_content']
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[enable_frontpage_content]', array(
	'label'       => esc_html__( 'Enable Content', 'kids-education-pro' ),
	'description' => esc_html__( 'Check to enable content on static front page only.', 'kids-education-pro' ),
	'section'     => 'kids_education_pro_static_homepage',
	'type'        => 'checkbox'
) );

// Add background property setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[static_homepage_background_property]', array(
	'default'           => $options['static_homepage_background_property'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[static_homepage_background_property]', array(
	'label'           	=> esc_html__( 'Select background property', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_static_homepage',
	'active_callback' 	=> 'kids_education_pro_static_homepage_content_active',
	'type'				=> 'select',
	'choices'			=> array(
		'background_image' => esc_html__( 'Background Image', 'kids-education-pro' ),
		'background_color' => esc_html__( 'Background Color', 'kids-education-pro' ), 
	)
) );

// Add background image setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[static_homepage_background_image]', array(
	'default'           => $options['static_homepage_background_image'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[static_homepage_background_image]',
    array(
		'label'           => esc_html__( 'Upload a background image', 'kids-education-pro' ),
		'description'     => esc_html__( 'Recommended background image size is 1920x420 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_static_homepage',
		'active_callback' => 'kids_education_pro_is_static_homepage_background_property_image',
   )
));

// Add background color setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[static_homepage_background_color]', array(
	'default'           => $options['static_homepage_background_color'],
	'sanitize_callback' => 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[static_homepage_background_color]', array(
	'label'        => esc_html__( 'Background Color', 'kids-education-pro' ),
	'section'    => 'kids_education_pro_static_homepage',
	'active_callback' => 'kids_education_pro_is_static_homepage_background_property_color',
) ) );