<?php
/**
 * search_course section
 *
 * This is the template for the content of search_course section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( class_exists( 'TP_Education' ) ) :
    if ( ! function_exists( 'kids_education_pro_add_search_course_section' ) ) :
        /**
        * Add search_course section
        *
        *@since Kids Education Pro 1.0
        */
        function kids_education_pro_add_search_course_section() {
            // Check if search_course is enabled on frontpage
            $search_course_enable = apply_filters( 'kids_education_pro_section_status', true, 'search_course_enable' );
            if ( true !== $search_course_enable ) {
                return false;
            }

            // Render search_course section now.
            kids_education_pro_render_search_course_section();
        }
    endif;
    add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_search_course_section', 40 );

    if ( ! function_exists( 'kids_education_pro_render_search_course_section' ) ) :
        /**
        * Start search_course section
        *
        * @return string search_course content
        * @since Kids Education Pro 1.0
        *
        */
        function kids_education_pro_render_search_course_section() {
            $options        = kids_education_pro_get_theme_options(); // get theme options
            $background_property = $options['search_course_background_property'];

            $background_css = !empty( $options['search_course_background_image'] ) ? 'style="background-image:url('.  esc_url( $options['search_course_background_image'] ) .')"' : '';

            if( 'background_color' == $background_property ){
                $background_css = !empty( $options['search_course_background_color'] ) ? 'style="background-color:'.  esc_attr( $options['search_course_background_color'] ) .'"' : '';
            }

            $section_class = ( 'disabled' == $options['features_enable'] ) ? '' : ' move-section-up ';

            $section_bottom_disabled = kids_education_pro_search_course_no_margin_top();

            if( ! empty( $section_bottom_disabled ) ){
                $section_class .= ' no-margin-top ';
            }

            $section_class .= ( 'disabled' != $options['recent_enable'] ) ? ' no-padding-bottom ' : '';
        ?>
            <section id="search-course-tab" class="page-section <?php echo esc_attr( $section_class ); ?> background-image-properties os-animation" data-os-animation="fadeIn" <?php echo $background_css; ?>>
                <div class="container">
                    <div class="entry-content">
                        <?php echo do_shortcode( '[TP_EDUCATION_SEARCH_TAB]' ); ?>
                    </div><!-- .entry-content -->
                </div><!-- .container -->
            </section><!-- .search-course-tab -->
        <?php 
        }
    endif;
endif;